==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/openShop/UnifiedShopCertificationInfo.java <==
package eleme.openapi.sdk.api.entity.openShop;


import eleme.openapi.sdk.api.entity.openShop.*;
import java.util.*;
import java.math.BigDecimal;


public class UnifiedShopCertificationInfo{

    /**
     * 证件类型
     */
    private Integer type;
    public Integer getType() {
        return type;
    }
    public void setType(Integer type) {
        this.type = type;
    }
    
    /**
     * 法人
     */
    private String legalPerson;
    public String getLegalPerson() {
        return legalPerson;
    }
    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }
    
    /**
     * 资质企业负责人
     */
    private String businessPerson;
    public String getBusinessPerson() {
        return businessPerson;
    }
    public void setBusinessPerson(String businessPerson) {
        this.businessPerson = businessPerson;
    }
    
    /**
     * 资质名称
     */
    private String licenseName;
    public String getLicenseName() {
        return licenseName;
    }
    public void setLicenseName(String licenseName) {
        this.licenseName = licenseName;
    }
    
    /**
     * 企业名称
     */
    private String name;
    public String getName() {
        return name;
    }
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * 证件号码
     */
    private String number;
    public String getNumber() {
        return number;
    }
    public void setNumber(String number) {
        this.number = number;
    }
    
    /**
     * 证件地址
     */
    private String address;
    public String getAddress() {
        return address;
    }
    public void setAddress(String address) {
        this.address = address;
    }
    
    /**
     * 证件有效期
     */
    private DateInfo validTime;
    public DateInfo getValidTime() {
        return validTime;
    }
    public void setValidTime(DateInfo validTime) {
        this.validTime = validTime;
    }
    
    /**
     * 经营方式
     */
    private String businessType;
    public String getBusinessType() {
        return businessType;
    }
    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }
    
    /**
     * 营业项目
     */
    private String scope;
    public String getScope() {
        return scope;
    }
    public void setScope(String scope) {
        this.scope = scope;
    }
    
    /**
     * 主体业态
     */
    private String mainBusiness;
    public String getMainBusiness() {
        return mainBusiness;
    }
    public void setMainBusiness(String mainBusiness) {
        this.mainBusiness = mainBusiness;
    }
    
    /**
     * 证件图片
     */
    private List<ImageInfo> images;
    public List<ImageInfo> getImages() {
        return images;
    }
    public void setImages(List<ImageInfo> images) {
        this.images = images;
    }
    
}

==> eleme-openapi-sdk-1.30.85-sources.jar: eleme/openapi/sdk/api/entity/openShop/UnifiedShopCertificationInfo.java <==
package eleme.openapi.sdk.api.entity.openShop;

import eleme.openapi.sdk.api.enumeration.openShop.*;
import eleme.openapi.sdk.api.entity.openShop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class UnifiedShopCertificationInfo{

    /**
     * 证件类型
     */
    private Integer type;
    public Integer getType() {
        return type;
    }
    public void setType(Integer type) {
        this.type = type;
    }
    
    /**
     * 法人
     */
    private String legalPerson;
    public String getLegalPerson() {
        return legalPerson;
    }
    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }
    
    /**
     * 资质企业负责人
     */
    private String businessPerson;
    public String getBusinessPerson() {
        return businessPerson;
    }
    public void setBusinessPerson(String businessPerson) {
        this.businessPerson = businessPerson;
    }
    
    /**
     * 资质名称
     */
    private String licenseName;
    public String getLicenseName() {
        return licenseName;
    }
    public void setLicenseName(String licenseName) {
        this.licenseName = licenseName;
    }
    
    /**
     * 企业名称
     */
    private String name;
    public String getName() {
        return name;
    }
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * 证件号码
     */
    private String number;
    public String getNumber() {
        return number;
    }
    public void setNumber(String number) {
        this.number = number;
    }
    
    /**
     * 证件地址
     */
    private String address;
    public String getAddress() {
        return address;
    }
    public void setAddress(String address) {
        this.address = address;
    }
    
    /**
     * 证件有效期
     */
    private DateInfo validTime;
    public DateInfo getValidTime() {
        return validTime;
    }
    public void setValidTime(DateInfo validTime) {
        this.validTime = validTime;
    }
    
    /**
     * 经营方式
     */
    private String businessType;
    public String getBusinessType() {
        return businessType;
    }
    public void setBusinessType(String businessType) {
        this.businessType = businessType;
    }
    
    /**
     * 营业项目
     */
    private String scope;
    public String getScope() {
        return scope;
    }
    public void setScope(String scope) {
        this.scope = scope;
    }
    
    /**
     * 主体业态
     */
    private String mainBusiness;
    public String getMainBusiness() {
        return mainBusiness;
    }
    public void setMainBusiness(String mainBusiness) {
        this.mainBusiness = mainBusiness;
    }
    
    /**
     * 证件图片
     */
    private List<ImageInfo> images;
    public List<ImageInfo> getImages() {
        return images;
    }
    public void setImages(List<ImageInfo> images) {
        this.images = images;
    }
    
}
